package com.ningdatech.pmapi.common.helper;


import com.ningdatech.pmapi.sys.model.dto.RegionDTO;
import com.ningdatech.pmapi.sys.model.dto.RegionTreeDTO;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * RegionCacheHelper -
 * </p>
 *
 * @author WendyYang
 * @since 13:50 2023/3/1
 */
public interface RegionCacheHelper {


    /**
     * 获取完整的区域树状结构
     *
     * @return /
     */
    List<RegionTreeDTO> all();

    /**
     * 获取用于前端回显示使用的unionList 仅用于返回前端的时候使用
     *
     * @param code  区域编码
     * @param level 区域层级
     * @return
     */
    String getUnionPathStr(String code, Integer level);

    /**
     * 原专家库数据导入使用 返回名称区域Map
     *
     * @return
     */
    Map<String, RegionDTO> getNameRegionMap();


    /**
     * key.getRegionCode() + "###" + key.getRegionLevel() ，regionMap.get(key)
     *
     * @return
     */
    Map<String, RegionDTO> getRegionMap();

    /**
     * 获取市级区域列表
     *
     * @return
     */
    List<RegionDTO> getMunicipalRegion();

    /**
     * 获取省级区域列表
     *
     * @return /
     */
    List<RegionDTO> getProvincialRegion();

    /**
     * 根据区域code 区域层级获取 区域类
     *
     * @param code  区域编码
     * @param level 区域层级
     * @return /
     */
    RegionDTO getByCodeAndLevel(String code, int level);

    /**
     * 根据传入的地区code与level获取所有上层地区集合
     * 按照level升序排列
     *
     * @param code  地区编码
     * @param level 地区层级
     * @return /
     */
    List<RegionDTO> listParents(String code, int level);

    /**
     * 获取所有区域编码「parent -> child」
     *
     * @param regionCode  区域编码
     * @param regionLevel 级别
     * @return /
     */
    List<String> getRegionCodes(String regionCode, int regionLevel);

    /**
     * 获取当前区域所有的子集
     *
     * @param code  区域编码
     * @param level 级别
     * @return /
     */
    List<String> getAllChildrenRegionCodeList(String code, int level);


    /**
     * 获取 根节点 区域层级编码
     *
     * @return /
     */
    String getParentCodeRoot();

}
